package com.gic.demo.project.web.controller;

import com.gic.demo.base.api.common.ServiceResponse;
import com.gic.demo.common.utils.GicDemoResponse;
import com.gic.demo.project.api.dto.DemoStoreDTO;
import com.gic.demo.project.api.service.DemoStoreApiService;
import com.gic.demo.project.web.exception.GicDemoErrCode;
import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;

/**
 * 指标管理接口
 *
 * @author zhurz
 */
@RestController
@RequestMapping("/demo")
public class DemoProjectController extends WebBaseController {

    private static final Logger logger = LoggerFactory.getLogger(DemoProjectController.class);

    @Autowired
    private DemoStoreApiService demoStoreApiService;

    /**
     * 获取门店信息
     *
     * @param storeId 门店id
     * @return
     */
    @RequestMapping("/get-store-info")
    public GicDemoResponse getStoreInfo(String storeId) {
        if (StringUtils.isBlank(storeId)) {
            return resultResponse(GicDemoErrCode.ERR_2);
        }
        ServiceResponse<DemoStoreDTO> response = demoStoreApiService.findDemoStoreById(storeId);
        if (response.isSuccess()) {
            return resultResponse(GicDemoErrCode.ERR_1, response.getResult());
        }
        logger.warn("获取门店信息异常 -> {} -> {}", storeId, response.getMessage());
        return resultResponse(GicDemoErrCode.ERR_0);
    }
}